%define srcname stone_soup

Name:           crawl
Version:        0.26.1
Release:        %mkrel 1
Summary:        Dungeon Crawl Stone Soup, a roguelike RPG with 2D or ascii graphics
License:        GPLv2+
Group:          Games/Adventure
Url:            https://crawl.develz.org
Source0:        https://github.com/crawl/crawl/releases/download/%{version}/%{srcname}-%{version}-nodeps.tar.xz

BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  fonts-ttf-dejavu
BuildRequires:  imagemagick
BuildRequires:  lua5.1-devel
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(pyyaml)

%description
Dungeon Crawl Stone Soup is a free rogue-like game of exploration and
treasure-hunting in dungeons filled with dangerous and unfriendly
monsters in a quest for the mystifyingly fabulous Orb of Zot.

The game has diverse species and many different character backgrounds
to choose from, deep tactical game-play, sophisticated magic, religion
and skill systems, and a grand variety of monsters to fight and run
from, making each game unique and challenging.

%package        common-data
Summary:        Common data for both game versions
Group:          Games/Adventure
BuildArch:      noarch

%description    common-data
This package contains common data used by the console and the tiles
version of the game.

%package        console
Summary:        Console version of Dungeon Crawl Stone Soup, a roguelike RPG
Group:          Games/Adventure
Requires:       %{name}-common-data = %{version}-%{release}
Provides:       %{name} = %{version}-%{release}

%description    console
Dungeon Crawl Stone Soup is a free rogue-like game of exploration and
treasure-hunting in dungeons filled with dangerous and unfriendly
monsters in a quest for the mystifyingly fabulous Orb of Zot.

The game has diverse species and many different character backgrounds
to choose from, deep tactical game-play, sophisticated magic, religion
and skill systems, and a grand variety of monsters to fight and run
from, making each game unique and challenging.

This package contains the console version of Dungeon Crawl Stone Soup
(with ASCII characters). You can find a graphical version
with tiles in the package crawl-tiles.

%package        tiles
Summary:        Tiles version of Dungeon Crawl Stone Soup, a rogue-like RPG
Group:          Games/Adventure
Requires:       %{name}-common-data = %{version}-%{release}
Provides:       %{name} = %{version}-%{release}

%description    tiles
Dungeon Crawl Stone Soup is a free rogue-like game of exploration and
treasure-hunting in dungeons filled with dangerous and unfriendly
monsters in a quest for the mystifyingly fabulous Orb of Zot.

The game has diverse species and many different character backgrounds
to choose from, deep tactical game-play, sophisticated magic, religion
and skill systems, and a grand variety of monsters to fight and run
from, making each game unique and challenging.

This package contains the tiles version of Dungeon Crawl Stone Soup.
You can find a console version with ASCII characters in the package
crawl-console.

%prep
%autosetup -p1 -n %{srcname}-%{version}

%{py3_shebang_fix} .

%define commonflags prefix=%{_prefix} DATADIR=%{_gamesdatadir}/%{name} BINDIR=%{_gamesbindir} \\\
                    EXTERNAL_FLAGS="%{optflags}" EXTERNAL_LDFLAGS="%{ldflags}" NO_TRY_LLD=y

%build
pushd source
%make_build %{commonflags}
mv %{name} %{name}-console
%make_build %{commonflags} TILES=y
popd

%install
# Binaries
%make_install -C source %{commonflags} TILES=y
mv %{buildroot}%{_gamesbindir}/%{name} %{buildroot}%{_gamesbindir}/%{name}-tiles
install -m0755 source/%{name}-console %{buildroot}%{_gamesbindir}

# Symbolic link for crawl-console (used e.g. by noteye)
ln -s %{_gamesbindir}/%{name}-console %{buildroot}%{_gamesbindir}/%{name}

# Man page
install -D -m0644 docs/%{name}.6 %{buildroot}%{_mandir}/man6/%{name}.6

# Icons
convert source/util/%{name}.ico %{name}.png
install -D -m644 %{name}-6.png %{buildroot}%{_iconsdir}/hicolor/256x256/apps/%{name}.png
install -D -m644 %{name}-7.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png
install -D -m644 %{name}-8.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
install -D -m644 %{name}-9.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png
install -D -m644 source/util/dcss.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg

# Menu entry
mkdir -p %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Dungeon Crawl Stone Soup
Comment=Roguelike game with 2D graphics
GenericName=Roguelike game
Exec=%{name}-tiles
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
Categories=Game;RolePlaying;
EOF

%files      common-data
%license LICENSE
%{_gamesdatadir}/%{name}/dat/
# Note: Some docs are loaded by the engine, shouldn't be moved (mga#28808).
%{_gamesdatadir}/%{name}/docs/
%{_gamesdatadir}/%{name}/settings/
%{_mandir}/man6/%{name}.6*
%exclude %{_gamesdatadir}/%{name}/dat/tiles/

%files      console
%{_gamesbindir}/%{name}
%{_gamesbindir}/%{name}-console

%files      tiles
%{_gamesbindir}/%{name}-tiles
%{_gamesdatadir}/%{name}/dat/tiles/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*


%changelog
* Tue Apr 20 2021 akien <akien> 0.26.1-1.mga8
+ Revision: 1717366
- Version 0.26.1
- Package docs as data like the engine wants it (mga#28808)

* Tue Jan 26 2021 akien <akien> 0.26.0-1.mga8
+ Revision: 1673414
- Version 0.26.0

* Mon Oct 19 2020 akien <akien> 0.25.1-1.mga8
+ Revision: 1637000
- Version 0.25.1

* Tue Apr 28 2020 akien <akien> 0.24.1-2.ga250c9d538.1.mga8
+ Revision: 1572696
- Update to stone_soup-0.24 branch tip a250c9d538 (pre 0.24.2), fixes more security concerns

* Tue Apr 28 2020 akien <akien> 0.24.1-1.mga8
+ Revision: 1572693
- Version 0.24.1, includes upstream's CVE-2020-11722 fix

* Tue Apr 28 2020 akien <akien> 0.24.0-3.mga8
+ Revision: 1572677
- Add patch to fix CVE-2020-11722 (mga#26552)

* Mon Feb 17 2020 umeabot <umeabot> 0.24.0-2.mga8
+ Revision: 1537506
- Mageia 8 Mass Rebuild

* Thu Oct 31 2019 akien <akien> 0.24.0-1.mga8
+ Revision: 1457136
- Version 0.24.0

* Tue Sep 17 2019 daviddavid <daviddavid> 0.23.2-2.mga8
+ Revision: 1442742
- port to Python 3

* Fri Apr 19 2019 akien <akien> 0.23.2-1.mga7
+ Revision: 1393649
- Version 0.23.2

* Fri Oct 19 2018 akien <akien> 0.22.1-1.mga7
+ Revision: 1322329
- Version 0.22.1

* Sun Sep 23 2018 umeabot <umeabot> 0.22.0-2.mga7
+ Revision: 1296899
- Mageia 7 Mass Rebuild

* Sat Aug 11 2018 akien <akien> 0.22.0-1.mga7
+ Revision: 1251049
- Version 0.22.0

* Thu Feb 08 2018 akien <akien> 0.21.1-1.mga7
+ Revision: 1199708
- Version 0.21.1

* Sat Jan 06 2018 akien <akien> 0.21.0-1.mga7
+ Revision: 1191016
- Fix bogus BR on pkgconfig(lua) (was and should be lua5.1-devel)
- Version 0.21.0

* Sun Jul 02 2017 akien <akien> 0.20.1-1.mga6
+ Revision: 1108959
- Version 0.20.1

* Thu May 25 2017 akien <akien> 0.20.0-1.mga6
+ Revision: 1104607
- Version 0.20.0

* Thu Mar 02 2017 akien <akien> 0.19.5-1.mga6
+ Revision: 1088505
- Version 0.19.5

* Tue Jan 31 2017 akien <akien> 0.19.4-1.mga6
+ Revision: 1084381
- Version 0.19.4

* Sun Jan 22 2017 akien <akien> 0.19.3-1.mga6
+ Revision: 1082899
- Version 0.19.3

* Thu Nov 24 2016 akien <akien> 0.19.1-1.mga6
+ Revision: 1069700
- Version 0.19.1

* Tue Nov 01 2016 akien <akien> 0.19.0-1.mga6
+ Revision: 1064531
- Version 0.19.0

* Mon May 09 2016 akien <akien> 0.18.1-1.mga6
+ Revision: 1011559
- Version 0.18.1
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Fri Dec 11 2015 akien <akien> 0.17.1-1.mga6
+ Revision: 909399
- Version 0.17.1
- Version 0.17.1
- Version 0.17.0

* Sat Sep 05 2015 akien <akien> 0.16.2-1.mga6
+ Revision: 872945
- Version 0.16.2

* Tue Jun 23 2015 akien <akien> 0.16.1-1.mga6
+ Revision: 840579
- Switch BRs to SDL2
- Version 0.16.1

* Sat Nov 15 2014 akien <akien> 0.15.2-2.mga5
+ Revision: 797338
- Add crawl symbolic link for crawl-console

* Thu Oct 23 2014 akien <akien> 0.15.2-1.mga5
+ Revision: 792708
- Version 0.15.2

* Wed Oct 15 2014 umeabot <umeabot> 0.15.1-2.mga5
+ Revision: 749664
- Second Mageia 5 Mass Rebuild

* Sun Sep 21 2014 akien <akien> 0.15.1-1.mga5
+ Revision: 707808
- Version 0.15.1

* Tue Sep 16 2014 umeabot <umeabot> 0.15.0-2.mga5
+ Revision: 678583
- Mageia 5 Mass Rebuild

* Thu Aug 28 2014 akien <akien> 0.15.0-1.mga5
+ Revision: 668951
- Version 0.15.0
- Install the manpage

* Tue Apr 29 2014 akien <akien> 0.14.1-1.mga5
+ Revision: 618909
- Bugfix version 0.14.1

* Wed Apr 09 2014 akien <akien> 0.14.0-1.mga5
+ Revision: 613073
- Final version of 0.14.0: https://gitorious.org/crawl/crawl/blobs/stone_soup-0.14/crawl-ref/docs/changelog.txt

* Mon Mar 31 2014 akien <akien> 0.14.0-0.beta1.1.mga5
+ Revision: 610749
- New version 0.14.0 beta1

* Thu Nov 28 2013 akien <akien> 0.13.1-1.mga4
+ Revision: 554016
- New upstream version 0.13.1: http://crawl.develz.org/main/0.13.1.txt

* Tue Oct 22 2013 umeabot <umeabot> 0.13.0-2.mga4
+ Revision: 541456
- Mageia 4 Mass Rebuild

* Sat Oct 12 2013 akien <akien> 0.13.0-1.mga4
+ Revision: 495829
- New version 0.13.0: http://crawl.develz.org/main/0.13.0.txt
- New version 0.12.3: http://crawl.develz.org/main/0.12.3.txt

* Sat Jul 27 2013 akien <akien> 0.12.2-1.mga4
+ Revision: 459042
- Update to upstream version 0.12.2: https://gitorious.org/crawl/crawl/blobs/stone_soup-0.12/crawl-ref/docs/changelog.txt
- BuildRequires added on libpng-devel and libSDL-devel (following upstream INSTALL.txt)
- BuildRequires added on libmesaglu1-devel to allow building the tiles version (dependancy _not_ listed in INSTALL.txt)
- Improved the layout of the specfile (tabulations vs spaces)

* Fri Jan 11 2013 umeabot <umeabot> 0.11.1-2.mga3
+ Revision: 348295
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 akien <akien> 0.11.1-1.mga3
+ Revision: 343052
- Added BuildRequires on fonts-ttf-dejavu, necessary for crawl-tiles.
- Moved the tiles from the package crawl-common-data to the package crawl-tiles.
- Updated the %%files section.
- Changed BuildArch to noarch for data package.
- Update to version 0.11.1. No other packaging changes.

* Mon Jul 23 2012 obgr_seneca <obgr_seneca> 0.10.3-2.mga3
+ Revision: 273682
- Removed second menu subcategory

* Thu Jul 19 2012 akien <akien> 0.10.3-1.mga3
+ Revision: 272531
- Update of crawl from version 0.10.0 to 0.10.3. Several important fixes in the SPEC file (see bug #6519)
+ obgr_seneca <obgr_seneca>
- added missing br for imagemagick

* Tue Mar 06 2012 akien <akien> 0.10.0-1.mga2
+ Revision: 220420
- Update of crawl to version 0.10.0

* Tue Nov 29 2011 akien <akien> 0.9.1-1.mga2
+ Revision: 174314
- Addition of missing BuildRequires: SDL_image-devel, pkgsubmit(freetype)
- Added a missing build dependency:  zlib-devel
- removed sound enabling since there are no official nor redistributable sound files
- imported package crawl


* Sun Oct 30 2011 Rémi Verschelde <akien@mageia.org> 0.9.1-1.mga2
- Created for Mageia 2
